==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/views/express/ExpressViewFactory.java <==
package com.yifan.yf_ads.views.express;

import android.app.Activity;
import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.bean.ExpressAdBean;
import com.yifan.yf_ads.utils.FLog;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.StandardMessageCodec;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;


public class ExpressViewFactory extends PlatformViewFactory {
    private EventChannel.EventSink eventSink;
    private Activity activity;
    private static final String TAG = "ExpressViewFactory";
    private final Map<Integer, ExpressView> expressFeedViewMap;

    public ExpressViewFactory() {
        super(StandardMessageCodec.INSTANCE);
        FLog.i(TAG, "ExpressFeedViewFactory construct");
        expressFeedViewMap = new HashMap<>();
    }

    public void setActivity(Activity activity) {
        FLog.i(TAG, "setActivity");
        this.activity = activity;
    }

    public void setEventSink(EventChannel.EventSink eventSink) {
        FLog.i(TAG, "setEventSink");
        this.eventSink = eventSink;
    }

    public void releaseExpressFeedViewCache() {
        FLog.i(TAG, "releaseExpressFeedViewCache");
        if (expressFeedViewMap != null) {
            for (Map.Entry<Integer, ExpressView> entry : expressFeedViewMap.entrySet()) {
                ExpressView childView = entry.getValue();
                if (childView != null) {
                    childView.releaseAd();
                }
            }
            expressFeedViewMap.clear();
        }
    }

    @NonNull
    @Override
    public PlatformView create(@NonNull Context context, int id, @Nullable Object args) {
        if (activity == null) {
            FLog.i(TAG, "activity == null");
            return null;
        }
        final String parameters = (String) args;
        try {
            ExpressAdBean creationParams = ExpressAdBean.parseObject(parameters);
            int uniqueKey = creationParams.getUniqueKey();
            FLog.i(TAG, "create uniqueKey:" + uniqueKey);
            if (expressFeedViewMap.containsKey(uniqueKey)) {
                ExpressView cachedView = expressFeedViewMap.get(uniqueKey);
                if (cachedView != null) {
                    FLog.i(TAG, "hit cached native view");
                    return cachedView;
                }
            }
            ExpressView expressFeedView = new ExpressView(activity, uniqueKey, creationParams, this.eventSink);
            expressFeedViewMap.put(uniqueKey, expressFeedView);
            return expressFeedView;
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return null;
    }
}

==> 0.0.9.tar.gz: android/src/main/java/com/yifan/yf_ads/views/express/ExpressViewFactory.java <==
package com.yifan.yf_ads.views.express;

import android.app.Activity;
import android.content.Context;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.bean.ExpressAdBean;
import com.yifan.yf_ads.utils.FLog;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.StandardMessageCodec;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;


public class ExpressViewFactory extends PlatformViewFactory {
    private EventChannel.EventSink eventSink;
    private Activity activity;
    private static final String TAG = "ExpressViewFactory";
    private final Map<String, ExpressView> expressFeedViewMap;

    public ExpressViewFactory() {
        super(StandardMessageCodec.INSTANCE);
        FLog.i(TAG, "ExpressFeedViewFactory construct");
        expressFeedViewMap = new HashMap<>();
    }

    public void setActivity(Activity activity) {
        FLog.i(TAG, "setActivity");
        this.activity = activity;
    }

    public void setEventSink(EventChannel.EventSink eventSink) {
        FLog.i(TAG, "setEventSink");
        this.eventSink = eventSink;
    }

    public void releaseExpressFeedViewCache() {
        FLog.i(TAG, "releaseExpressFeedViewCache");
        if (expressFeedViewMap != null) {
            for (Map.Entry<String, ExpressView> entry : expressFeedViewMap.entrySet()) {
                ExpressView childView = entry.getValue();
                if (childView != null) {
                    childView.releaseAd();
                }
            }
            expressFeedViewMap.clear();
        }
    }

    public void requestExpressView(@Nullable Object args) {
        if (activity == null) {
            FLog.i(TAG, "activity == null");
        }
        final String parameters = (String) args;
        try {
            ExpressAdBean creationParams = ExpressAdBean.parseObject(parameters);
            String uniqueKey = creationParams.getUniqueKey();
            FLog.i(TAG, "create uniqueKey:" + uniqueKey);
            if (expressFeedViewMap.containsKey(uniqueKey)) {
                ExpressView cachedView = expressFeedViewMap.get(uniqueKey);
                if (cachedView != null) {
                    FLog.i(TAG, "hit cached native view");
                    return;
                }
            }
            ExpressView expressFeedView = new ExpressView(activity, uniqueKey, creationParams, this.eventSink,
                    viewId -> {
                        if (expressFeedViewMap != null) {
                            expressFeedViewMap.remove(viewId);
                        }
                        FLog.i(TAG, "request remove cached success " + viewId);
                    });
            expressFeedViewMap.put(uniqueKey, expressFeedView);
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    @NonNull
    @Override
    public PlatformView create(@NonNull Context context, int id, @Nullable Object args) {
        if (activity == null) {
            FLog.i(TAG, "activity == null");
            return null;
        }
        final String parameters = (String) args;
        try {
            ExpressAdBean creationParams = ExpressAdBean.parseObject(parameters);
            String uniqueKey = creationParams.getUniqueKey();
            FLog.i(TAG, "create uniqueKey:" + uniqueKey);
            if (expressFeedViewMap.containsKey(uniqueKey)) {
                ExpressView cachedView = expressFeedViewMap.get(uniqueKey);
                if (cachedView != null) {
                    FLog.i(TAG, "hit cached native view");
                    if (!cachedView.isShow()) {
                        cachedView.showAd(activity);
                    }
                    return cachedView;
                }
            }
            ExpressView expressFeedView = new ExpressView(activity, uniqueKey, creationParams, this.eventSink,
                    viewId -> {
                        expressFeedViewMap.remove(viewId);
                        FLog.i(TAG, "remove cached success " + viewId);
                    });
            expressFeedViewMap.put(uniqueKey, expressFeedView);
            return expressFeedView;
        } catch (Throwable e) {
            e.printStackTrace();
        }
        return null;
    }
}
